@@ -1,25 +1,18 @@
-
-#
-# HTTP::Lite.pm
-#
-# $Id: Lite.pm,v 1.11 2002/06/13 19:53:48 rhooper Exp rhooper $
-#
-
 package HTTP::Lite;
 
-use vars qw($VERSION);
-use strict qw(vars);
-
-$VERSION = "2.1.6";
-my $BLOCKSIZE = 65536;
-my $CRLF = "\r\n";
-my $URLENCODE_VALID = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_-.";
-
-# Required modules for Network I/O
+use 5.005;
+use strict;
+use warnings;
 use Socket 1.3;
 use Fcntl;
 use Errno qw(EAGAIN);
 
+our $VERSION = '2.44';
+
+my $BLOCKSIZE = 65536;
+my $CRLF = "\r\n";
+my $URLENCODE_VALID = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_-.";
+
 # Forward declarations
 sub prepare_post;
 sub http_write;
@@ -32,7 +25,7 @@ my @urlencode_valid;
 foreach my $char (split('', $URLENCODE_VALID)) {
   $urlencode_valid[ord $char]=$char;
 }
-for (my $n=0;$n<255;$n++) {
+for (my $n=0;$n<256;$n++) {
   if (!defined($urlencode_valid[$n])) {
     $urlencode_valid[$n]=sprintf("%%%02X", $n);
   }
@@ -144,7 +137,7 @@ sub request
 
   # Parse URL 
   my ($protocol,$host,$junk,$port,$object) = 
-    $url =~ m{^([^:/]+)://([^/:]*)(:(\d+))?(/.*)$};
+    $url =~ m{^([^:/]+)://([^/:]*)(:(\d+))?(/?.*)$};
 
   # Only HTTP is supported here
   if ($protocol ne "http")
@@ -451,6 +444,7 @@ sub add_req_header
   my $self = shift;
   my ($header, $value) = @_;
   
+  return unless defined($value);
   my $lcheader = lc($header);
   $self->{DEBUG} && $self->DEBUG("add_req_header $header $value");
   ${$self->{headers}}{$lcheader} = $value;
@@ -616,11 +610,13 @@ sub http_write
   }
 
   my $size = length($line);
-  my $bytes = syswrite($fh, $line, length($line) , 0 );  # please double check new length limit
-                                                         # is this ok?
-  while ( ($size - $bytes) > 0) {
-    $bytes += syswrite($fh, $line, length($line)-$bytes, $bytes );  # also here
-  }
+  my $total_sent = 0;
+  my $nbytes;
+  do {
+    $nbytes = syswrite($fh, $line, $size - $total_sent, $total_sent );
+    die $! unless(defined($nbytes) || $!{EAGAIN}); # non-recoverable error occurred! 
+    $total_sent += $nbytes;
+  } while ($total_sent < $size);
 }
  
 sub http_read
@@ -771,38 +767,41 @@ HTTP::Lite - Lightweight HTTP implementation
 =head1 SYNOPSIS
 
     use HTTP::Lite;
-    $http = new HTTP::Lite;
+    $http = HTTP::Lite->new;
     $req = $http->request("http://www.cpan.org/") 
         or die "Unable to get document: $!";
     print $http->body();
 
 =head1 DESCRIPTION
 
-    HTTP::Lite is a stand-alone lightweight HTTP/1.1 implementation
-    for perl.  It is not intended as a replacement for the
-    fully-features LWP module.  Instead, it is intended for use in
-    situations where it is desirable to install the minimal number of
-    modules to achieve HTTP support, or where LWP is not a good
-    candidate due to CPU overhead, such as slower processors.
-    HTTP::Lite is also significantly faster than LWP.
+B<Note:> you should look at L<HTTP::Tiny> or L<LWP>
+before using this module.
 
-    HTTP::Lite is ideal for CGI (or mod_perl) programs or for bundling
-    for redistribution with larger packages where only HTTP GET and
-    POST functionality are necessary.
+HTTP::Lite is a stand-alone lightweight HTTP/1.1 implementation
+for perl.  It is not intended as a replacement for the
+fully-featured LWP module.  Instead, it is intended for use in
+situations where it is desirable to install the minimal number of
+modules to achieve HTTP support, or where LWP is not a good
+candidate due to CPU overhead, such as slower processors.
+HTTP::Lite is also significantly faster than LWP.
 
-    HTTP::Lite supports basic POST and GET operations only.  As of
-    0.2.1, HTTP::Lite supports HTTP/1.1 and is compliant with the Host
-    header, necessary for name based virtual hosting.  Additionally,
-    HTTP::Lite now supports Proxies.
+HTTP::Lite is ideal for CGI (or mod_perl) programs or for bundling
+for redistribution with larger packages where only HTTP GET and
+POST functionality are necessary.
 
-    As of 2.0.0 HTTP::Lite now supports a callback to allow processing
-    of request data as it arrives.  This is useful for handling very
-    large files without consuming memory.
+HTTP::Lite supports basic POST and GET operations only.  As of
+0.2.1, HTTP::Lite supports HTTP/1.1 and is compliant with the Host
+header, necessary for name based virtual hosting.  Additionally,
+HTTP::Lite now supports Proxies.
 
-    If you require more functionality, such as FTP or HTTPS, please
-    see libwwwperl (LWP).  LWP is a significantly better and more
-    comprehensive package than HTTP::Lite, and should be used instead
-    of HTTP::Lite whenever possible.
+As of 2.0.0 HTTP::Lite now supports a callback to allow processing
+of request data as it arrives.  This is useful for handling very
+large files without consuming memory.
+
+If you require more functionality, such as FTP or HTTPS, please
+see libwwwperl (LWP).  LWP is a significantly better and more
+comprehensive package than HTTP::Lite, and should be used instead
+of HTTP::Lite whenever possible.
 
 =head1 CONSTRUCTOR
 
@@ -829,7 +828,7 @@ status code will be returned.  200 series status codes represent
 success, 300 represent temporary errors, 400 represent permanent
 errors, and 500 represent server errors.
 
-See F<http://www.w3.org/Protocols/HTTP/HTRESP.html> for detailled
+See F<http://www.w3.org/Protocols/HTTP/HTRESP.html> for detailed
 information about HTTP status codes.
 
 The $data_callback parameter, if used, is a way to filter the data as it is
@@ -855,7 +854,7 @@ An example use to save a document to file is:
   }
 
   $url = "$testpath/bigbinary.dat";
-  open OUT, ">bigbinary.dat";
+  open OUT, '>','bigbinary.dat';
   $res = $http->request($url, \&savetofile, OUT);
   close OUT;
 
@@ -863,7 +862,7 @@ An example use to save a document to file is:
 
 At various stages of the request, callbacks may be used to modify the
 behaviour or to monitor the status of the request.  These work like the
-$data_callback parameter to request(), but are more verstaile.  Using
+$data_callback parameter to request(), but are more versatile.  Using
 set_callback disables $data_callback in request()
 
 The callbacks are called as: 
@@ -873,18 +872,18 @@ The current phases are:
 
   connect - connection has been established and headers are being
             transmitted.
-            
+
   content-length - return value is used as the content-length.  If undef,
             and prepare_post() was used, the content length is
             calculated.
-                   
+
   done-headers - all headers have been sent
-  
+
   content - return value is used as content and is sent to client.  Return
             undef to use the internal content defined by prepare_post().
-            
+
   content-done - content has been successfuly transmitted.
-  
+
   data - A block of data has been received.  The data is referenced by
             $dataref.  The return value is dereferenced and replaces the
             content passed in.  Return undef to avoid using memory for large
@@ -910,16 +909,19 @@ broken HTTP/1.1 servers.  Use 1 to enable HTTP/1.1 support.
 
 =item delete_req_header ( $header )
 
-Add, Delete, or a HTTP header(s) for the request.  These functions
+Add, Delete, or get a HTTP header(s) for the request.  These functions
 allow you to override any header.  Presently, Host, User-Agent,
 Content-Type, Accept, and Connection are pre-defined by the HTTP::Lite
 module.  You may not override Host, Connection, or Accept.
 
+If you call C<add_req_header()> with C<$value> set to C<undef>,
+then the header won't be added.
+
 To provide (proxy) authentication or authorization, you would use:
 
     use HTTP::Lite;
     use MIME::Base64;
-    $http = new HTTP::Lite;
+    $http = HTTP::Lite->new;
     $encoded = encode_base64('username:password');
     $http->add_req_header("Authorization", $encoded);
 
@@ -928,7 +930,7 @@ of each header.
 
 =item body
 
-Returns the body of the document retured by the remote server.
+Returns the body of the document returned by the remote server.
 
 =item headers_array
 
@@ -981,7 +983,7 @@ choose.
 
 =item local_port ( $port )
 
-Explicity select the local port.  0 (default and reccomended) lets the
+Explicity select the local port.  0 (default and recommended) lets the
 system choose.
 
 =item method ( $method )
@@ -989,12 +991,13 @@ system choose.
 Explicity set the method.  Using prepare_post or reset overrides this
 setting.  Usual choices are GET, POST, PUT, HEAD
 
+=back
 
 =head1 EXAMPLES
 
     # Get and print out the headers and body of the CPAN homepage
     use HTTP::Lite;
-    $http = new HTTP::Lite;
+    $http = HTTP::Lite->new;
     $req = $http->request("http://www.cpan.org/")
         or die "Unable to get document: $!";
     die "Request failed ($req): ".$http->status_message()
@@ -1010,7 +1013,7 @@ setting.  Usual choices are GET, POST, PUT, HEAD
 
     # POST a query to the dejanews USENET search engine
     use HTTP::Lite;
-    $http = new HTTP::Lite;
+    $http = HTTP::Lite->new;
     %vars = (
              "QRY" => "perl",
              "ST" => "MS",
@@ -1032,26 +1035,33 @@ setting.  Usual choices are GET, POST, PUT, HEAD
     - Redirects (Location) are not automatically followed
     - multipart/form-data POSTs are not directly supported (necessary
       for File uploads).
-    
+
 =head1 BUGS
 
-    Some broken HTTP/1.1 servers send incorrect chunk sizes
-    when transferring files.  HTTP/1.1 mode is now disabled by
-    default.
+Some broken HTTP/1.1 servers send incorrect chunk sizes when transferring files.
+HTTP/1.1 mode is now disabled by default.
 
 =head1 AUTHOR
 
 Roy Hooper <rhooper@thetoybox.org>
 
+Now co-maintained by Neil Bowers E<lt>neilb@cpan.orgE<gt>.
+
 =head1 SEE ALSO
 
-L<LWP>
-RFC 2068 - HTTP/1.1 -http://www.w3.org/
+This module (HTTP::Lite) is almost certainly not the best module for your needs.
+
+For most uses L<HTTP::Tiny> is a good choice.
+If you need more features, then look at L<LWP>.
+
+You could also read this L<review of CPAN modules for making HTTP requests|http://neilb.org/reviews/http-requesters.html>.
 
 =head1 COPYRIGHT
 
 Copyright (c) 2000-2002 Roy Hooper.  All rights reserved.
 
+Some parts copyright 2009 - 2010 Adam Kennedy.
+
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
